SUTRA2
===========
.. image:: https://readthedocs.org/projects/sutra2/badge/?version=latest&style=flat
                    :target: https://sutra2.readthedocs.io
.. image:: https://img.shields.io/travis/KWR-Water/sutra2
                    :target: https://travis-ci.com/KWR-Water/sutra2
.. image:: https://img.shields.io/codecov/c/gh/KWR-Water/sutra2
                    :target: https://codecov.io/gh/KWR-Water/sutra2


A tool to calculate the fate of Organic Micropollutant and pathogens in the subsoil.

See documentation_ for more information.


Installation
------------
To get the latest stable version, use::

  python -m pip install git+https://github.com/KWR-Water/sutra2.git@main

or::
  pip install git+ssh://git@github.com/KWR-Water/sutra2.git@main

License
-------

This package is MIT licensed. See `License File <https://github.com/KWR-Water/sutra2/blob/master/LICENSE>`__.

.. _documentation: https://sutra2.readthedocs.io/en/latest/
